---
title: <span class="badge builder"></span> ExprTypeClassicConditionsConditions
---
# <span class="badge builder"></span> ExprTypeClassicConditionsConditions

## Constructor

```python
ExprTypeClassicConditionsConditions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeClassicConditionsConditions
```

### <span class="badge object-method"></span> evaluator

```python
def evaluator(evaluator: cogbuilder.Builder[expr.ExprTypeClassicConditionsConditionsEvaluator]) -> typing.Self
```

### <span class="badge object-method"></span> operator

```python
def operator(operator: cogbuilder.Builder[expr.ExprTypeClassicConditionsConditionsOperator]) -> typing.Self
```

### <span class="badge object-method"></span> query

```python
def query(query: cogbuilder.Builder[expr.ExprTypeClassicConditionsConditionsQuery]) -> typing.Self
```

### <span class="badge object-method"></span> reducer

```python
def reducer(reducer: cogbuilder.Builder[expr.ExprTypeClassicConditionsConditionsReducer]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeClassicConditionsConditions](./object-ExprTypeClassicConditionsConditions.md)
